@@ -503,12 +503,12 @@ complete_login (passwd)
 	FILE *fd;
 
         /* When running under WinNT, password is always required. */
-	if (is_winnt || (!guest && (!pw || *pw->pw_passwd))) {
+	if (!guest && (is_winnt || !pw || *pw->pw_passwd)) {
                 int ret;
 
 #ifdef __CYGWIN__
                 if (is_winnt) {
-                    HANDLE hToken = cygwin_logon_user (pw, guest ? "" : passwd);
+                    HANDLE hToken = cygwin_logon_user (pw, passwd);
                     cygwin_set_impersonation_token (hToken);
                     ret = (hToken != INVALID_HANDLE_VALUE);
                 } else
